def add(a,b):
    return (a+b)

def subtract(a,b):
    return (a-b)

def multiply(a,b):
    return (a*b)

def divide(a,b):
    return (a/b)

def power(a,b):
    return (a**b)

def modulus(a,b):
    return (a%b)